module Cluster
  class Runner

    def run command, options = {}
      begin
        if !system command, options
          raise command.red
        end
      rescue Interrupt
        # user pressed Ctrl+C, do nothing
      end
    end

    def run_dc command, options = {}
      run "docker-compose -f ~/development/spend-cloud/docker-compose.yml #{command}", options
    end

    def start args, options
      if options.pull
        run_dc "pull"
      end

      if options.build
        run_dc "build #{options.pull ? "--pull" : ""}"
      end

      run "docker container prune -f"

      run_dc "up --detach"

      if options.pull or options.build
        system "docker image prune -f"
      end

      UI.success("\n✔️ You can visit your environment at 👉 https://spend-cloud.dev.spend.cloud 👌")
    end

    def stop
      run_dc "down --remove-orphans"
    end

    def restart
      run_dc "restart"
    end

    def delete
      run_dc "down --remove-orphans -v"
    end

    def reset args, options
      delete
      start args, options
    end

    def status
      run_dc "ps"
    end

    def logs args, options
      command = "logs"

      command << " --follow" if options.f or options.follow
      command << " --timestamps" if options.t or options.timestamps
      command << " --tail #{options.tail}" if options.tail

      run_dc "#{command} #{args.join " "}"
    end

  end
end
