require 'commander'
require 'sct/command'

module Sct
    class CommandsGenerator
        include Commander::Methods

        def self.start
            self.new.run
        end

        def run
            program :name, 'sct'
            program :version, Sct::VERSION
            program :summary, 'CLI helper tool for local SCT development'
            program :description, 'SCT is a CLI tool for developers using the Visma Continuous Deployment Model in conjunction with the Google Cloud Platform (GCP). It provides multiple command to set up and maintain a kubernetes cluster on a machine for local development'

            global_option('--verbose') { $verbose = true }

            command :'mysql-proxy' do |c|
                c.syntax = 'sct mysql-proxy'
                c.description = 'setup google mysql proxy'

                c.action do |args, options|
                    UI.important("Trying to setup mysql proxy")
                    Sct::MysqlproxyCommand.new.execute args, options
                end
            end

            command :'cluster' do |c|
                c.syntax = 'sct cluster'
                c.description = 'make changes to the cluster'
            end

            command :'shell' do |c|
                c.syntax = 'sct shell'
                c.description = 'run commands from the shell using docker containers'
                c.option '--root', 'run as root user in the container'

                c.action do |args, options|
                    Sct::ShellCommand.new.execute args, options
                end
            end

            command :'dev' do |c|
                c.syntax = 'sct dev'
                c.description = 'start development container in the current directory'
                c.option '--build', '(re)build images before starting'
                c.option '--pull', 'pull latest images before starting'
                c.option '--wsl-debugger', 'use if running the PHP debugger from WSL'

                c.action do |args, options|
                    Sct::DevCommand.new.execute args, options
                end
            end

            command :'database-pull' do |c|
                c.syntax = 'sct database pull'
                c.description = 'pull database changes for proactive frame and proactive config'
                c.option '--all', 'pull the database changes for all repositories'
                c.option '--proactive-frame', 'pull the database changes from proactive-frame'
                c.option '--proactive-config', 'pull the database changes from proactive-config'

                c.action do |args, options|
                    UI.important("Trying to pull database")
                    Sct::DatabasePullCommand.new.execute args, options
                end
            end

            run!
        end
    end
end
